<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/entity/RImageEntity.cpp" line="+86"/>
        <source>File</source>
        <translation>Fichero</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+69"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width Factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Factor de ancho</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height Factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Factor de altura</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+124"/>
        <source>Width</source>
        <translatorcomment>--exact match--
--file: es.po--
Ancho:
Ancho
A&amp;nchura papel:</translatorcomment>
        <translation>Ancho</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <source>Height</source>
        <translatorcomment>--exact match--
--file: es.po--
Alto:
Alto
Altura del Texto:</translatorcomment>
        <translation>Alto</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Fade</source>
        <translation>Difuminar</translation>
    </message>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="+87"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+75"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+101"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimAngular3PEntity.cpp" line="+97"/>
        <location line="+16"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+93"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="+97"/>
        <location line="+16"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="+99"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="+98"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="+99"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="+97"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+87"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+79"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+89"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-12"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+76"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+82"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="-2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-19"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+77"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+86"/>
        <location line="+3"/>
        <location line="+8"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+77"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>X</source>
        <translatorcomment>--exact match--
--file: es.po--
Saliendo de la aplicación...
Saliendo de la aplicación
Exportando el dibujo...</translatorcomment>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngular3PEntity.cpp" line="-16"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="-16"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-16"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: es.po--
Arco: centro, punto, ángulos
&amp;Centro, Punto, Angulo</translatorcomment>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="-1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimAngular3PEntity.cpp" line="-1"/>
        <location line="+16"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="-1"/>
        <location line="+16"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-1"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-1"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-14"/>
        <location line="+3"/>
        <location line="+8"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Y</source>
        <translatorcomment>--exact match--
--file: es.po--
Ubicando las Bibliotecas..
Ubicando las Bibliotecas
&amp;Modificar</translatorcomment>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimAngular3PEntity.cpp" line="-15"/>
        <location line="+16"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="-15"/>
        <location line="+16"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-14"/>
        <location line="+3"/>
        <location line="+8"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Z</source>
        <translatorcomment>--exact match--
--file: es.po--
Mosaico &amp;horizontal
Mosaico horizontal
Ocultar todo</translatorcomment>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <source>Radius</source>
        <translatorcomment>--exact match--
--file: es.po--
Especifique radio
Círculo: centro, radio</translatorcomment>
        <translation>Radio</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-9"/>
        <source>Start Angle</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Especifique ángulo de partida:
Especifique angulo de aranque</translatorcomment>
        <translation>Ángulo inicial</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>End Angle</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Especifique ángulo final o ángulo acorde a la longitud
Especifique ángulo final</translatorcomment>
        <translation>Ángulo final</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>Reversed</source>
        <translatorcomment>--exact match--
--file: qcadlib_es.ts--
Invertido</translatorcomment>
        <translation>Invertido</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+9"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+2"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+3"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+10"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+2"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-10"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+2"/>
        <source>Length</source>
        <translatorcomment>--exact match--
--file: es.po--
Longitud no válida
Especifique ángulo final o ángulo acorde a la longitud</translatorcomment>
        <translation>Longitud</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <source>Total Length</source>
        <translation>Largo total</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sweep Angle</source>
        <translation>Ángulo</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+2"/>
        <source>Total Area</source>
        <translation>Área total</translation>
    </message>
    <message>
        <source>Contents</source>
        <translatorcomment>--exact match--
--file: qtiplot_es.ts--
Pega el contenido del portapapeles
Editar el contenido del bloque seleccionado</translatorcomment>
        <translation type="obsolete">Contenidos</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="-12"/>
        <source>Solid</source>
        <translatorcomment>--exact match--
--file: Scripts_es.ts--
Dibujar sombreados y rellenos
Dibuja texturas y rellenos sólidos
Sombreado/Relleno</translatorcomment>
        <translation>Sólido</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Pattern</source>
        <translatorcomment>--exact match--
--file: es.po--
Patrón
Patrones Sombreado:</translatorcomment>
        <translation>Patrón</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Name</source>
        <translatorcomment>--exact match--
--file: es.po--
documento sin título %1
Guardando el dibujo con nombre nuevo...
Guardando el dibujo con nombre nuevo</translatorcomment>
        <translation>Nombre</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>From Entity</source>
        <translation>De entidad</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+8"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+2"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <source>Angle</source>
        <translatorcomment>--exact match--
--file: es.po--
Introducir ángulo:
Introducir ángulo
Introduzca ángulo en línea de cota:</translatorcomment>
        <translation>Ángulo</translation>
    </message>
    <message>
        <location line="+192"/>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+13"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-191"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+2"/>
        <source>Scale</source>
        <translatorcomment>--exact match--
--file: es.po--
Escalar
E&amp;scala</translatorcomment>
        <translation>Escalar</translation>
    </message>
    <message>
        <source>Simple</source>
        <translatorcomment>--google--
Texto simple
Nelder-Mead Simplex
El plugin no implementa un método %1 necesario para el ajuste simplex.</translatorcomment>
        <translation type="vanished">Simple</translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="vanished">Texto</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation type="vanished">Texto plano</translation>
    </message>
    <message>
        <source>Font Name</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Nombre de la fuente</translation>
    </message>
    <message>
        <source>Text Height</source>
        <translation type="vanished">Altura del texto</translation>
    </message>
    <message>
        <source>Text Angle</source>
        <translation type="vanished">Ángulo del texto</translation>
    </message>
    <message>
        <source>X Scale</source>
        <translation type="vanished">Escala X</translation>
    </message>
    <message>
        <source>Bold</source>
        <translatorcomment>--exact match--
--file: Text_es.ts--
&amp;Negrita
Negrita</translatorcomment>
        <translation type="vanished">Negrita</translation>
    </message>
    <message>
        <source>Italic</source>
        <translatorcomment>--exact match--
--file: Text_es.ts--
[10300-1032F] Old Italic
Itálica antigua</translatorcomment>
        <translation type="vanished">Cursivo</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translatorcomment>--google--
Espaciado de líneas:
&amp;Espacio entre líneas por defecto
Espacio entre líneas por defecto
Factor de Espaciado entre Líneas</translatorcomment>
        <translation type="vanished">Espacio entre líneas</translation>
    </message>
    <message>
        <source>Alignment</source>
        <translatorcomment>--exact match--
--file: es.po--
Alineación
Alineación@Vertical</translatorcomment>
        <translation type="vanished">Alineación</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translatorcomment>--exact match--
--file: es.po--
Mosaico &amp;horizontal
Mosaico horizontal
&amp;Horizontal</translatorcomment>
        <translation type="vanished">Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translatorcomment>--exact match--
--file: es.po--
Vertical
&amp;Vertical</translatorcomment>
        <translation type="vanished">Vertical</translation>
    </message>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="-5"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <source>Diameter</source>
        <translatorcomment>--exact match--
--file: Scripts_es.ts--
(Des)Activar signo de diámetro
ø (Diámetro)</translatorcomment>
        <translation>Diámetro</translation>
    </message>
    <message>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <source>Circumference</source>
        <translatorcomment>--google--
Mide el área y crcunferencia de un polígono
Circumferencia: %1</translatorcomment>
        <translation>Circunferencia</translation>
    </message>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="+4"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+10"/>
        <source>Area</source>
        <translatorcomment>--exact match--
--file: es.po--
Área de textura inválida. Verifique que las entidades seleccionadas formen un contorno cerrado.
Área de textura inválida. Verifique que las entidades seleccionadas formen un contorno cerrado
Area del &amp;Polígono</translatorcomment>
        <translation>Área</translation>
    </message>
    <message>
        <location filename="../src/entity/REllipseEntity.cpp" line="-17"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Major Point</source>
        <translatorcomment>--google--
Punto Mayor|X
Punto Mayor|Y
El punto principal de la elipse o radio mayor</translatorcomment>
        <translation>Punto mayor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ratio</source>
        <translatorcomment>--exact match--
--file: artisan_es.ts--
Proporción
Dibujar un arco elíptico desde el centro, punto principal, la relación y los ángulos</translatorcomment>
        <translation>Proporción</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start Parameter</source>
        <translatorcomment>--ignored case--
--file: EllipseArcCPPA_es.ts--
Parámetro de partida</translatorcomment>
        <translation>Parámetro de partida</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Parameter</source>
        <translatorcomment>--ignored case--
--file: EllipseArcCPPA_es.ts--
Parámetro final</translatorcomment>
        <translation>Parámetro final</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-7"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Point</source>
        <translatorcomment>--exact match--
--file: qtiplot_es.ts--
Punto inicial (y):
Punto inicial (y)
Punto inicial (x):</translatorcomment>
        <translation>Punto inicial</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Point</source>
        <translatorcomment>--exact match--
--file: qtiplot_es.ts--
Punto final (x):
Punto final (x)
Punto final (y):</translatorcomment>
        <translation>Punto final</translation>
    </message>
    <message>
        <source>Clockwise</source>
        <translation type="vanished">Sentido horario</translation>
    </message>
    <message>
        <source>Counterclockwise</source>
        <translation type="vanished">Sentido antihorario</translation>
    </message>
    <message>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-16"/>
        <source>Polyline Pattern</source>
        <translation>Patrón polilínea</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Closed</source>
        <translatorcomment>--exact match--
--file: es.po--
Área de textura inválida. Verifique que las entidades seleccionadas formen un contorno cerrado.
Área de textura inválida. Verifique que las entidades seleccionadas formen un contorno cerrado
No se puede agregar a una polínea cerrada.</translatorcomment>
        <translation>Cerrado</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Start Width</source>
        <translation>Ancho inicial</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Width</source>
        <translation>Ancho final</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Width</source>
        <translation>Ancho global</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orientation</source>
        <translation>Orientación</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Base Angle</source>
        <translation>Ángulo base</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Global Z</source>
        <translation>Z global</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-21"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+2"/>
        <location line="+1"/>
        <source>Vertex</source>
        <translatorcomment>--google--
Siguiente vértice
Primer vértice</translatorcomment>
        <translation>Vértice</translation>
    </message>
    <message>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-4"/>
        <source>Bulge</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Bulto</translation>
    </message>
    <message>
        <location filename="../src/entity/RSplineEntity.cpp" line="-10"/>
        <source>Closed Periodic</source>
        <translation>Cerrado periódico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translatorcomment>--exact match--
--file: Scripts_es.ts--
° (Grados)
Grados Decimales</translatorcomment>
        <translation>Grados</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Control Point</source>
        <translatorcomment>--google--
Especifique el primer punto de control
Especifique el siguiente punto de control o [%1]
Especifique el siguiente punto de control</translatorcomment>
        <translation>Punto de control</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Fit Point</source>
        <translatorcomment>--google--
Primer punto de ajuste
Punto de ajuste siguiente
&amp;Spline (puntos de ajuste)</translatorcomment>
        <translation>Punto de ajuste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Knot Vector</source>
        <translation>Vector de nudo</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Knot</source>
        <translation>Nudo</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Use Start Tangent</source>
        <translation>Utilice la tangente de inicio</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Tangent</source>
        <translation>Tangente inicial</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use End Tangent</source>
        <translation>Utilice la tangente del extremo</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Tangent</source>
        <translation>Tangente final</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Line</source>
        <translatorcomment>--google--
Especifique localización de la línea de cota
Introduzca ángulo en línea de cota:
Introduzca ángulo en línea de cota</translatorcomment>
        <translation>Línea de cota</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 1</source>
        <translatorcomment>--google--
Punto de Extensión 1|X
Punto de Extensión 1|Y</translatorcomment>
        <translation>Punto de extensión 1</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 2</source>
        <translatorcomment>--google--
Punto de Extensión 2|X
Punto de Extensión 2|Y</translatorcomment>
        <translation>Punto de extensión 2</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Línea 1 inicio</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 End</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Línea 1 fin</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Línea 2 inicio</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 End</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Línea 2 fin</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular3PEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Arc</source>
        <translatorcomment>--google--
Especifique localización de la línea de cota angular
Ubicación del arco dimensión</translatorcomment>
        <translation>Arco dimensión</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-6"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Chord Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cuerda punto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Far Chord Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cuerda punto 2</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-5"/>
        <location line="+1"/>
        <source>Origin</source>
        <translatorcomment>--exact match--
--file: qtiplot_es.ts--
Especifique el origen de la  primera línea de extensión
Especifique el origen de la  segunda línea de  extensión</translatorcomment>
        <translation>Origen</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate</source>
        <translatorcomment>--exact match--
--file: qcadactions_es.ts--
&amp;Ordinal
Ordinal
Cota ordinal</translatorcomment>
        <translation>Ordinal</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Defining Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punto de definición</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Leader End Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Guia punto final</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimRotatedEntity.cpp" line="+115"/>
        <source>Dimension Angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ángulo cota</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-21"/>
        <source>Label</source>
        <translatorcomment>--exact match--
--file: qtiplot_es.ts--
Etiqueta: 
Etiqueta
Insertar símbolo en la etiqueta</translatorcomment>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Tolerance</source>
        <translatorcomment>--exact match--
--file: es.po--
Toleranicia máxima
Tolerancia mínima</translatorcomment>
        <translation>Tolerancia</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Upper Limit</source>
        <translatorcomment>--ignored case--
--file: qtiplot_es.ts--
Límite superior</translatorcomment>
        <translation>Límite superior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lower Limit</source>
        <translatorcomment>--ignored case--
--file: qtiplot_es.ts--
Límite inferior</translatorcomment>
        <translation>Límite inferior</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Definition Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punto de definición</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Posición del texto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Flip First Arrow</source>
        <translation>Refleja la primera flecha</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Flip Second Arrow</source>
        <translation>Refleja la segunda flecha</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Auto Label</source>
        <translation>Auto etiqueta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Measured Value</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Valor medido</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear Factor</source>
        <translation>Factor</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block Name</source>
        <translation>Nombre del bloque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Auto Label Position</source>
        <translation>Auto Label Position</translation>
    </message>
    <message>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-4"/>
        <source>Arrow</source>
        <translatorcomment>--exact match--
--file: DimensionSettings_es.ts--
Directriz (secuencia de líneas con flecha)
Tamaño flecha:</translatorcomment>
        <translation>Flecha</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow Block</source>
        <translation>Flecha bloque</translation>
    </message>
    <message>
        <location filename="../src/entity/RFaceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 1</source>
        <translatorcomment>--google--
Punto de Extensión 1|X
Punto de Extensión 1|Y
Punto 1|X</translatorcomment>
        <translation>Punto 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 2</source>
        <translatorcomment>--google--
Punto de Extensión 2|X
Punto de Extensión 2|Y
Punto 2|X</translatorcomment>
        <translation>Punto 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 3</source>
        <translatorcomment>--google--
Punto 3|X
Punto 3|Y</translatorcomment>
        <translation>Punto 3</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 4</source>
        <translatorcomment>--google--
Punto 4|X
Punto 4|Y</translatorcomment>
        <translation>Punto 4</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeDefinitionEntity.cpp" line="+89"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+89"/>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prompt</source>
        <translation>Indicador</translation>
    </message>
    <message>
        <location filename="../src/entity/RRayEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Base Point</source>
        <translation>Punto base</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Second Point</source>
        <translation>Segundo punto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction Vector</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+3"/>
        <source>Fixed Angle</source>
        <translation>Ángulo fijo</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+1"/>
        <source>Invisible</source>
        <translation>Invisible</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="+2"/>
        <source>Arc Symbol Type</source>
        <translation>Símbolo de arco</translation>
    </message>
</context>
</TS>
